@@ -3,11 +3,10 @@
 
 
 orderMCMCbasemax<-function(n,nsmall,startorder,iterations,stepsave,moveprobs,parenttable,scoretable,aliases,numparents,
-                           rowmaps,maxmatrices,numberofparentsvec,gamma=1,bgnodes,matsize) {
+                           rowmaps,maxmatrices,numberofparentsvec,gamma=1,bgnodes,matsize,chainout=FALSE,compress=TRUE) {
+  
+  result<-list()
   
-  #n - number of nodes (background included)
-  #nsmall - number of nodes excluding background
-  #matsize - number of rows/columns in adjacency matrix 
   
   if(!is.null(bgnodes)) {
     mainnodes<-c(1:matsize)[-bgnodes]
@@ -35,6 +34,8 @@ orderMCMCbasemax<-function(n,nsmall,startorder,iterations,stepsave,moveprobs,par
   L2[1]<-currentDAG$logscore #starting DAG score
   L3[1]<-currenttotallogscore #starting order score
   L4[[1]]<-currentpermy[1:nsmall] #starting order
+  maxdag<-currentDAG$incidence
+  maxscore<-L2[1]
   
   moveprobsstart<-moveprobs
   
@@ -88,16 +89,27 @@ orderMCMCbasemax<-function(n,nsmall,startorder,iterations,stepsave,moveprobs,par
     }
     currentDAG<-samplescoreplus1.max(n,mainnodes,currentorderscores,plus1lists=NULL,maxmatrices,scoretable,
                                      parenttable,numberofparentsvec,aliases)
-    L1[[z]]<-currentDAG$incidence #store adjacency matrix of a sampled DAG each 'stepsave'
+    if(chainout) {
+      if(compress) {
+        L1[[z]]<-Matrix(currentDAG$incidence,sparse=TRUE) #store compressed adjacency matrix of a sampled DAG each 'stepsave'
+      } else {
+        L1[[z]]<-currentDAG$incidence #store adjacency matrix of a sampled DAG each 'stepsave'
+      }
+    }
     L2[z]<-currentDAG$logscore #and log score of a sampled DAG
     L3[z]<-currenttotallogscore #and the current order score
     L4[[z]]<-currentpermy[1:nsmall] #and store current order
+    if(L2[z]>maxscore) {
+      maxscore<-L2[z]
+      maxdag<-currentDAG$incidence
+    } 
   }
-  result<-list()
   result$incidence<-L1
   result$DAGscores<-L2
   result$orderscores<-L3
   result$orders<-L4
+  result$maxscore<-maxscore
+  result$maxdag<-maxdag
 
   return(result)
 }
