@@ -2,11 +2,10 @@
 #partly derived from <doi:10.1080/01621459.2015.1133426>
 
 orderMCMCplus1<-function(n,nsmall,startorder,iterations,stepsave,moveprobs,parenttable,scoretable,aliases,numparents,rowmaps,
-                         plus1lists,scoresmatrices,numberofparentsvec,gamma=1,bgnodes, matsize){
+                         plus1lists,scoresmatrices,numberofparentsvec,gamma=1,bgnodes,matsize,chainout=FALSE,compress=TRUE){
+  
+  result<-list()
   
-  #n - number of nodes (background included)
-  #nsmall - number of nodes excluding background
-  #matsize - number of rows/columns in adjacency matrix 
   
   if(!is.null(bgnodes)) {
     mainnodes<-c(1:matsize)[-bgnodes]
@@ -34,6 +33,8 @@ orderMCMCplus1<-function(n,nsmall,startorder,iterations,stepsave,moveprobs,paren
   L2[1]<-currentDAG$logscore #starting DAG score
   L3[1]<-currenttotallogscore #starting order score
   L4[[1]]<-currentpermy[1:nsmall] #starting order
+  maxdag<-currentDAG$incidence
+  maxscore<-L2[1]
   
   
   for (z in 2:zlimit){ #the MCMC chain loop with 'iteration' steps is in two parts
@@ -87,16 +88,28 @@ orderMCMCplus1<-function(n,nsmall,startorder,iterations,stepsave,moveprobs,paren
     }
     currentDAG<-samplescoreplus1(matsize,mainnodes,currentorderscores,plus1lists,scoretable,scoresmatrices,
                                  parenttable,numberofparentsvec,aliases)
-    L1[[z]]<-currentDAG$incidence #store adjacency matrix of a sampled DAG each 'stepsave'
+    if(chainout) {
+      if(compress) {
+        L1[[z]]<-Matrix(currentDAG$incidence,sparse=TRUE) #store compressed adjacency matrix of a sampled DAG each 'stepsave'
+      } else {
+        L1[[z]]<-currentDAG$incidence #store adjacency matrix of a sampled DAG each 'stepsave'
+      }
+    }
     L2[z]<-currentDAG$logscore #and log score of a sampled DAG
     L3[z]<-currenttotallogscore #and the current order score
     L4[[z]]<-currentpermy[1:nsmall] #and store current order
+    if(L2[z]>maxscore) {
+      maxscore<-L2[z]
+      maxdag<-currentDAG$incidence
+    } 
   }
-  result<-list()
+
   result$incidence<-L1
   result$DAGscores<-L2
   result$orderscores<-L3
   result$orders<-L4
+  result$maxscore<-maxscore
+  result$maxdag<-maxdag
 
   return(result)
 }
